<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyAddBranchRequest;
use App\Http\Requests\StoreAddBranchRequest;
use App\Http\Requests\UpdateAddBranchRequest;
use App\Models\AddBranch;
use App\Models\City;
use App\Models\State;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class AddBranchController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('add_branch_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $addBranches = AddBranch::with(['state', 'city', 'media'])->get();

        $states = State::get();

        $cities = City::get();

        return view('admin.addBranches.index', compact('addBranches', 'states', 'cities'));
    }

    public function create()
    {
        abort_if(Gate::denies('add_branch_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cities = City::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.addBranches.create', compact('states', 'cities'));
    }

    public function store(StoreAddBranchRequest $request)
    {
        $addBranch = AddBranch::create($request->all());

        if ($request->input('gst', false)) {
            $addBranch->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $addBranch->id]);
        }

        return redirect()->route('admin.add-branches.index');
    }

    public function edit(AddBranch $addBranch)
    {
        abort_if(Gate::denies('add_branch_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $states = State::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $cities = City::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $addBranch->load('state', 'city');

        return view('admin.addBranches.edit', compact('states', 'cities', 'addBranch'));
    }

    public function update(UpdateAddBranchRequest $request, AddBranch $addBranch)
    {
        $addBranch->update($request->all());

        if ($request->input('gst', false)) {
            if (!$addBranch->gst || $request->input('gst') !== $addBranch->gst->file_name) {
                if ($addBranch->gst) {
                    $addBranch->gst->delete();
                }
                $addBranch->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
            }
        } elseif ($addBranch->gst) {
            $addBranch->gst->delete();
        }

        return redirect()->route('admin.add-branches.index');
    }

    public function show(AddBranch $addBranch)
    {
        abort_if(Gate::denies('add_branch_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $addBranch->load('state', 'city');

        return view('admin.addBranches.show', compact('addBranch'));
    }

    public function destroy(AddBranch $addBranch)
    {
        abort_if(Gate::denies('add_branch_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $addBranch->delete();

        return back();
    }

    public function massDestroy(MassDestroyAddBranchRequest $request)
    {
        AddBranch::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('add_branch_create') && Gate::denies('add_branch_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new AddBranch();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
