<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyContainerSizeRequest;
use App\Http\Requests\StoreContainerSizeRequest;
use App\Http\Requests\UpdateContainerSizeRequest;
use App\Models\ContainerSize;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ContainerSizeController extends Controller
{
    use CsvImportTrait;

    public function index()
    {
        abort_if(Gate::denies('container_size_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $containerSizes = ContainerSize::all();

        return view('admin.containerSizes.index', compact('containerSizes'));
    }

    public function create()
    {
        abort_if(Gate::denies('container_size_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.containerSizes.create');
    }

    public function store(StoreContainerSizeRequest $request)
    {
        $containerSize = ContainerSize::create($request->all());

        return redirect()->route('admin.container-sizes.index');
    }

    public function edit(ContainerSize $containerSize)
    {
        abort_if(Gate::denies('container_size_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.containerSizes.edit', compact('containerSize'));
    }

    public function update(UpdateContainerSizeRequest $request, ContainerSize $containerSize)
    {
        $containerSize->update($request->all());

        return redirect()->route('admin.container-sizes.index');
    }

    public function show(ContainerSize $containerSize)
    {
        abort_if(Gate::denies('container_size_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.containerSizes.show', compact('containerSize'));
    }

    public function destroy(ContainerSize $containerSize)
    {
        abort_if(Gate::denies('container_size_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $containerSize->delete();

        return back();
    }

    public function massDestroy(MassDestroyContainerSizeRequest $request)
    {
        ContainerSize::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
