<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroyPortRequest;
use App\Http\Requests\StorePortRequest;
use App\Http\Requests\UpdatePortRequest;
use App\Models\Port;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class PortsController extends Controller
{
    use CsvImportTrait;

    public function index()
    {
        abort_if(Gate::denies('port_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $ports = Port::all();

        return view('admin.ports.index', compact('ports'));
    }

    public function create()
    {
        abort_if(Gate::denies('port_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.ports.create');
    }

    public function store(StorePortRequest $request)
    {
        $port = Port::create($request->all());

        return redirect()->route('admin.ports.index');
    }

    public function edit(Port $port)
    {
        abort_if(Gate::denies('port_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.ports.edit', compact('port'));
    }

    public function update(UpdatePortRequest $request, Port $port)
    {
        $port->update($request->all());

        return redirect()->route('admin.ports.index');
    }

    public function show(Port $port)
    {
        abort_if(Gate::denies('port_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.ports.show', compact('port'));
    }

    public function destroy(Port $port)
    {
        abort_if(Gate::denies('port_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $port->delete();

        return back();
    }

    public function massDestroy(MassDestroyPortRequest $request)
    {
        Port::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function portstatus(Request $request)
    {
     // return $request->all();
      //  $user = Subcategories::find($request->user_id);
       $port = Port::where('id',$request->id)->update(['status' => $request->status ]);
      if($port)
        {
         return response()->json(['success'=>'success']);
        }else
        {
           return response()->json(['errors'=>'errors']);
        } 
    }
}
