<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyRegisteredExporterRequest;
use App\Http\Requests\StoreRegisteredExporterRequest;
use App\Http\Requests\UpdateRegisteredExporterRequest;
use App\Models\RegisteredExporter;
use App\Models\Team;
use Gate;
use Illuminate\Http\Request;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class RegisteredExportersController extends Controller
{
    use MediaUploadingTrait;
    use CsvImportTrait;

    public function index()
    {
        abort_if(Gate::denies('registered_exporter_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $registeredExporters = RegisteredExporter::with(['team', 'media'])->get();

        $teams = Team::get();

        return view('admin.registeredExporters.index', compact('registeredExporters', 'teams'));
    }

    public function create()
    {
        abort_if(Gate::denies('registered_exporter_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.registeredExporters.create');
    }

    public function store(StoreRegisteredExporterRequest $request)
    {
        $registeredExporter = RegisteredExporter::create($request->all());

        if ($request->input('gst', false)) {
            $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
        }

        if ($request->input('iec', false)) {
            $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
        }

        if ($request->input('pan', false)) {
            $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
        }

        if ($request->input('cancelled_cheque', false)) {
            $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
        }

        if ($request->input('self_certification', false)) {
            $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $registeredExporter->id]);
        }

        return redirect()->route('admin.registered-exporters.index');
    }

    public function edit(RegisteredExporter $registeredExporter)
    {
        abort_if(Gate::denies('registered_exporter_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $registeredExporter->load('team');

        return view('admin.registeredExporters.edit', compact('registeredExporter'));
    }

    public function update(UpdateRegisteredExporterRequest $request, RegisteredExporter $registeredExporter)
    {
        $registeredExporter->update($request->all());

        if ($request->input('gst', false)) {
            if (!$registeredExporter->gst || $request->input('gst') !== $registeredExporter->gst->file_name) {
                if ($registeredExporter->gst) {
                    $registeredExporter->gst->delete();
                }
                $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
            }
        } elseif ($registeredExporter->gst) {
            $registeredExporter->gst->delete();
        }

        if ($request->input('iec', false)) {
            if (!$registeredExporter->iec || $request->input('iec') !== $registeredExporter->iec->file_name) {
                if ($registeredExporter->iec) {
                    $registeredExporter->iec->delete();
                }
                $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('iec'))))->toMediaCollection('iec');
            }
        } elseif ($registeredExporter->iec) {
            $registeredExporter->iec->delete();
        }

        if ($request->input('pan', false)) {
            if (!$registeredExporter->pan || $request->input('pan') !== $registeredExporter->pan->file_name) {
                if ($registeredExporter->pan) {
                    $registeredExporter->pan->delete();
                }
                $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('pan'))))->toMediaCollection('pan');
            }
        } elseif ($registeredExporter->pan) {
            $registeredExporter->pan->delete();
        }

        if ($request->input('cancelled_cheque', false)) {
            if (!$registeredExporter->cancelled_cheque || $request->input('cancelled_cheque') !== $registeredExporter->cancelled_cheque->file_name) {
                if ($registeredExporter->cancelled_cheque) {
                    $registeredExporter->cancelled_cheque->delete();
                }
                $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('cancelled_cheque'))))->toMediaCollection('cancelled_cheque');
            }
        } elseif ($registeredExporter->cancelled_cheque) {
            $registeredExporter->cancelled_cheque->delete();
        }

        if ($request->input('self_certification', false)) {
            if (!$registeredExporter->self_certification || $request->input('self_certification') !== $registeredExporter->self_certification->file_name) {
                if ($registeredExporter->self_certification) {
                    $registeredExporter->self_certification->delete();
                }
                $registeredExporter->addMedia(storage_path('tmp/uploads/' . basename($request->input('self_certification'))))->toMediaCollection('self_certification');
            }
        } elseif ($registeredExporter->self_certification) {
            $registeredExporter->self_certification->delete();
        }

        return redirect()->route('admin.registered-exporters.index');
    }

    public function show(RegisteredExporter $registeredExporter)
    {
        abort_if(Gate::denies('registered_exporter_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $registeredExporter->load('team');

        return view('admin.registeredExporters.show', compact('registeredExporter'));
    }

    public function destroy(RegisteredExporter $registeredExporter)
    {
        abort_if(Gate::denies('registered_exporter_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $registeredExporter->delete();

        return back();
    }

    public function massDestroy(MassDestroyRegisteredExporterRequest $request)
    {
        RegisteredExporter::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        abort_if(Gate::denies('registered_exporter_create') && Gate::denies('registered_exporter_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new RegisteredExporter();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
