<?php

namespace App\Http\Controllers\Admin;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\CsvImportTrait;
use App\Http\Requests\MassDestroySealRequest;
use App\Http\Requests\StoreSealRequest;
use App\Http\Requests\UpdateSealRequest;
use App\Models\Seal;
use App\Models\Suplier;
use App\Models\Team;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use DB;

class SealsController extends Controller
{
    use CsvImportTrait;

    public function index()
    {
        abort_if(Gate::denies('seal_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $seals = Seal::with(['supplier', 'team'])->get();

        $supliers = Suplier::get();

        $teams = Team::get();

        return view('admin.seals.index', compact('seals', 'supliers', 'teams'));
    }

    public function create()
    {
      abort_if(Gate::denies('seal_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

      $exporters= DB::table('users') ->join('role_user', function ($join) { $join->on('users.id', '=', 'role_user.user_id') ->where('role_user.role_id', '=', '3'); }) ->get();

        $suppliers = Suplier::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $seals =DB::table('salescount')->select('totalcount')->first();
        $totalcount =  $seals->totalcount;

        return view('admin.seals.create', compact('suppliers', 'exporters','totalcount'));
    }

    public function store(StoreSealRequest $request)
    {
        $request->exporter_id;
        if(!empty($request->exporter_id)){
        $update = \DB::table('seals')->where('seal_status', 'Credited') ->limit($request->number_of_e_seals) ->orderBy('id', 'ASC') ->update( ['seal_status' => 'Debited','exporter_id' => $request->exporter_id] ); 

       // return $seal = Seal::update(array_merge($request->all(), ['seal_status' => 'Debited']))->orderBy('id', 'DESC')->limit($request->number_of_e_seals);    
        $updatedcountseal = $request->totalcount-$request->number_of_e_seals;
          $seal = DB::table('salescount')->update(['totalcount' => $updatedcountseal]);     
        }else{
            //return 2;
          $seal = Seal::create(array_merge($request->all(), ['seal_status' => 'Credited']));  
        $updatedcountseal = $request->totalcount+$request->number_of_e_seals;
          $seal = DB::table('salescount')->update(['totalcount' => $updatedcountseal]);  
        }
       

        return redirect()->route('admin.seals.index');
    }

/*    public function store(StoreSealRequest $request)
    {
        $seal = Seal::create($request->all());

        return redirect()->route('admin.seals.index');
    }*/

    public function edit(Seal $seal)
    {
        abort_if(Gate::denies('seal_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $suppliers = Suplier::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $seal->load('supplier', 'team');

        return view('admin.seals.edit', compact('suppliers', 'seal'));
    }

    public function update(UpdateSealRequest $request, Seal $seal)
    {
        $seal->update($request->all());

        return redirect()->route('admin.seals.index');
    }

    public function show(Seal $seal)
    {
        abort_if(Gate::denies('seal_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $seal->load('supplier', 'team');

        return view('admin.seals.show', compact('seal'));
    }

    public function destroy(Seal $seal)
    {
        abort_if(Gate::denies('seal_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $seal->delete();

        return back();
    }

    public function massDestroy(MassDestroySealRequest $request)
    {
        Seal::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
