<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\StoreAddBranchRequest;
use App\Http\Requests\UpdateAddBranchRequest;
use App\Http\Resources\Admin\AddBranchResource;
use App\Models\AddBranch;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class AddBranchApiController extends Controller
{
    use MediaUploadingTrait;

    public function index()
    {
        abort_if(Gate::denies('add_branch_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AddBranchResource(AddBranch::with(['state', 'city'])->get());
    }

    public function store(StoreAddBranchRequest $request)
    {
        $addBranch = AddBranch::create($request->all());

        if ($request->input('gst', false)) {
            $addBranch->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
        }

        return (new AddBranchResource($addBranch))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(AddBranch $addBranch)
    {
        abort_if(Gate::denies('add_branch_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new AddBranchResource($addBranch->load(['state', 'city']));
    }

    public function update(UpdateAddBranchRequest $request, AddBranch $addBranch)
    {
        $addBranch->update($request->all());

        if ($request->input('gst', false)) {
            if (!$addBranch->gst || $request->input('gst') !== $addBranch->gst->file_name) {
                if ($addBranch->gst) {
                    $addBranch->gst->delete();
                }
                $addBranch->addMedia(storage_path('tmp/uploads/' . basename($request->input('gst'))))->toMediaCollection('gst');
            }
        } elseif ($addBranch->gst) {
            $addBranch->gst->delete();
        }

        return (new AddBranchResource($addBranch))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(AddBranch $addBranch)
    {
        abort_if(Gate::denies('add_branch_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $addBranch->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
