<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StorePortRequest;
use App\Http\Requests\UpdatePortRequest;
use App\Http\Resources\Admin\PortResource;
use App\Models\Port;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class PortsApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('port_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PortResource(Port::all());
    }

    public function store(StorePortRequest $request)
    {
        $port = Port::create($request->all());

        return (new PortResource($port))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(Port $port)
    {
        abort_if(Gate::denies('port_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PortResource($port);
    }

    public function update(UpdatePortRequest $request, Port $port)
    {
        $port->update($request->all());

        return (new PortResource($port))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(Port $port)
    {
        abort_if(Gate::denies('port_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $port->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
