<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Esealtracking extends Model
{
    use SoftDeletes;
    use HasFactory;

    public $table = 'esealtrackings';

    protected $dates = [
        'sealing_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'truckno',
        'container_no',
        'size',
        'eseal_no',
        'shipping_bill',
        'shipping_date',
        'sealing_date',
        'custodian_name',
        'reach_time',
        'status',
        'remark',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public static function boot()
    {
        parent::boot();
        Esealtracking::observe(new \App\Observers\EsealtrackingActionObserver());
    }

    public function getSealingDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setSealingDateAttribute($value)
    {
        $this->attributes['sealing_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
