<?php

namespace App\Models;

use \DateTimeInterface;
use App\Traits\MultiTenantModelTrait;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Export extends Model
{
    use SoftDeletes;
    use MultiTenantModelTrait;
    use HasFactory;

    public $table = 'exports';

    protected $dates = [
        'sealing_date',
        'shipping_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'trailer_reg_number',
        'driver_license',
        'driver_name',
        'container_number',
        'terminal_document',
        'destination_custom_id',
        'eseal_id',
        'shipping_bill',
        'sealing_date',
        'shipping_date',
        'created_at',
        'container_size_id',
        'updated_at',
        'deleted_at',
        'exporter_id',
        'truck_no',
        'status',
        'remarks',
        'team_id',
    ];

    public function destination_custom()
    {
        return $this->belongsTo(Port::class, 'destination_custom_id');
    }

    public function eseal()
    {
        return $this->belongsTo(Seal::class, 'eseal_id');
    }

    public function getSealingDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setSealingDateAttribute($value)
    {
        $this->attributes['sealing_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getShippingDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setShippingDateAttribute($value)
    {
        $this->attributes['shipping_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function container_size()
    {
        return $this->belongsTo(ContainerSize::class, 'container_size_id');
    }

    public function team()
    {
        return $this->belongsTo(Team::class, 'team_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
