<?php

namespace App\Models;

use \DateTimeInterface;
use App\Traits\MultiTenantModelTrait;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class RegisteredExporter extends Model implements HasMedia
{
    use SoftDeletes;
    use MultiTenantModelTrait;
    use InteractsWithMedia;
    use HasFactory;

    public $table = 'registered_exporters';

    protected $appends = [
        'gst',
        'iec',
        'pan',
        'cancelled_cheque',
        'self_certification',
    ];

    protected $dates = [
        'self_sealing_approval_date',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'import_export_code',
        'exporter_company_name',
        'contact_mobile_no',
        'gst_number',
        'pan_number',
        'email',
        'address',
        'postal_code',
        'self_sealing_approval_no',
        'self_sealing_approval_date',
        'self_sealing_approved_by',
        'commissionerate_address',
        'created_at',
        'updated_at',
        'deleted_at',
        'team_id',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function getSelfSealingApprovalDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setSelfSealingApprovalDateAttribute($value)
    {
        $this->attributes['self_sealing_approval_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getGstAttribute()
    {
        return $this->getMedia('gst')->last();
    }

    public function getIecAttribute()
    {
        return $this->getMedia('iec')->last();
    }

    public function getPanAttribute()
    {
        return $this->getMedia('pan')->last();
    }

    public function getCancelledChequeAttribute()
    {
        return $this->getMedia('cancelled_cheque')->last();
    }

    public function getSelfCertificationAttribute()
    {
        return $this->getMedia('self_certification')->last();
    }

    public function team()
    {
        return $this->belongsTo(Team::class, 'team_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
