<?php

namespace App\Models;

use \DateTimeInterface;
use App\Traits\MultiTenantModelTrait;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Seal extends Model
{
    use SoftDeletes;
    use MultiTenantModelTrait;
    use HasFactory;

    public $table = 'seals';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'supplier_id',
        'sn',
        'tid',
        'epc',
        'exporter_id',
        'reach_time',
        'used',
        'used_time',
        'seal_status',
        'created_at',
        'updated_at',
        'deleted_at',
        'number_of_e_seals',
        'team_id',
    ];

    public static function boot()
    {
        parent::boot();
        Seal::observe(new \App\Observers\SealActionObserver());
    }

    public function supplier()
    {
        return $this->belongsTo(Suplier::class, 'supplier_id');
    }

    public function team()
    {
        return $this->belongsTo(Team::class, 'team_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
