@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.export.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.exports.update", [$export->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label class="required" for="trailer_reg_number">{{ trans('cruds.export.fields.trailer_reg_number') }}</label>
                <input class="form-control {{ $errors->has('trailer_reg_number') ? 'is-invalid' : '' }}" type="text" name="trailer_reg_number" id="trailer_reg_number" value="{{ old('trailer_reg_number', $export->trailer_reg_number) }}" required>
                @if($errors->has('trailer_reg_number'))
                    <div class="invalid-feedback">
                        {{ $errors->first('trailer_reg_number') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.trailer_reg_number_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="driver_license">{{ trans('cruds.export.fields.driver_license') }}</label>
                <input class="form-control {{ $errors->has('driver_license') ? 'is-invalid' : '' }}" type="text" name="driver_license" id="driver_license" value="{{ old('driver_license', $export->driver_license) }}" required>
                @if($errors->has('driver_license'))
                    <div class="invalid-feedback">
                        {{ $errors->first('driver_license') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.driver_license_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="driver_name">{{ trans('cruds.export.fields.driver_name') }}</label>
                <input class="form-control {{ $errors->has('driver_name') ? 'is-invalid' : '' }}" type="text" name="driver_name" id="driver_name" value="{{ old('driver_name', $export->driver_name) }}" required>
                @if($errors->has('driver_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('driver_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.driver_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="container_number">{{ trans('cruds.export.fields.container_number') }}</label>
                <input class="form-control {{ $errors->has('container_number') ? 'is-invalid' : '' }}" type="text" name="container_number" id="container_number" value="{{ old('container_number', $export->container_number) }}">
                @if($errors->has('container_number'))
                    <div class="invalid-feedback">
                        {{ $errors->first('container_number') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.container_number_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="terminal_document">{{ trans('cruds.export.fields.terminal_document') }}</label>
                <input class="form-control {{ $errors->has('terminal_document') ? 'is-invalid' : '' }}" type="text" name="terminal_document" id="terminal_document" value="{{ old('terminal_document', $export->terminal_document) }}">
                @if($errors->has('terminal_document'))
                    <div class="invalid-feedback">
                        {{ $errors->first('terminal_document') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.terminal_document_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="destination_custom_id">{{ trans('cruds.export.fields.destination_custom') }}</label>
                <select class="form-control select2 {{ $errors->has('destination_custom') ? 'is-invalid' : '' }}" name="destination_custom_id" id="destination_custom_id">
                    @foreach($destination_customs as $id => $entry)
                        <option value="{{ $id }}" {{ (old('destination_custom_id') ? old('destination_custom_id') : $export->destination_custom->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('destination_custom'))
                    <div class="invalid-feedback">
                        {{ $errors->first('destination_custom') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.destination_custom_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="eseal_id">{{ trans('cruds.export.fields.eseal') }}</label>
                <select class="form-control select2 {{ $errors->has('eseal') ? 'is-invalid' : '' }}" name="eseal_id" id="eseal_id" required>
                    @foreach($eseals as $id => $entry)
                        <option value="{{ $id }}" {{ (old('eseal_id') ? old('eseal_id') : $export->eseal->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('eseal'))
                    <div class="invalid-feedback">
                        {{ $errors->first('eseal') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.eseal_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="shipping_bill">{{ trans('cruds.export.fields.shipping_bill') }}</label>
                <input class="form-control {{ $errors->has('shipping_bill') ? 'is-invalid' : '' }}" type="text" name="shipping_bill" id="shipping_bill" value="{{ old('shipping_bill', $export->shipping_bill) }}">
                @if($errors->has('shipping_bill'))
                    <div class="invalid-feedback">
                        {{ $errors->first('shipping_bill') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.shipping_bill_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="sealing_date">{{ trans('cruds.export.fields.sealing_date') }}</label>
                <input class="form-control date {{ $errors->has('sealing_date') ? 'is-invalid' : '' }}" type="text" name="sealing_date" id="sealing_date" value="{{ old('sealing_date', $export->sealing_date) }}" required>
                @if($errors->has('sealing_date'))
                    <div class="invalid-feedback">
                        {{ $errors->first('sealing_date') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.sealing_date_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="shipping_date">{{ trans('cruds.export.fields.shipping_date') }}</label>
                <input class="form-control date {{ $errors->has('shipping_date') ? 'is-invalid' : '' }}" type="text" name="shipping_date" id="shipping_date" value="{{ old('shipping_date', $export->shipping_date) }}" required>
                @if($errors->has('shipping_date'))
                    <div class="invalid-feedback">
                        {{ $errors->first('shipping_date') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.shipping_date_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="container_size_id">{{ trans('cruds.export.fields.container_size') }}</label>
                <select class="form-control select2 {{ $errors->has('container_size') ? 'is-invalid' : '' }}" name="container_size_id" id="container_size_id">
                    @foreach($container_sizes as $id => $entry)
                        <option value="{{ $id }}" {{ (old('container_size_id') ? old('container_size_id') : $export->container_size->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('container_size'))
                    <div class="invalid-feedback">
                        {{ $errors->first('container_size') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.export.fields.container_size_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection