@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.user.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("admin.users.update", [$user->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label class="required" for="name">{{ trans('cruds.user.fields.name') }}</label>
                <input class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}" type="text" name="name" id="name" value="{{ old('name', $user->name) }}" required>
                @if($errors->has('name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="email">{{ trans('cruds.user.fields.email') }}</label>
                <input class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}" type="email" name="email" id="email" value="{{ old('email', $user->email) }}" required>
                @if($errors->has('email'))
                    <div class="invalid-feedback">
                        {{ $errors->first('email') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.email_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="password">{{ trans('cruds.user.fields.password') }}</label>
                <input class="form-control {{ $errors->has('password') ? 'is-invalid' : '' }}" type="password" name="password" id="password">
                @if($errors->has('password'))
                    <div class="invalid-feedback">
                        {{ $errors->first('password') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.password_helper') }}</span>
            </div>
            <div class="form-group">
                <div class="form-check {{ $errors->has('approved') ? 'is-invalid' : '' }}">
                    <input type="hidden" name="approved" value="0">
                    <input class="form-check-input" type="checkbox" name="approved" id="approved" value="1" {{ $user->approved || old('approved', 0) === 1 ? 'checked' : '' }}>
                    <label class="form-check-label" for="approved">{{ trans('cruds.user.fields.approved') }}</label>
                </div>
                @if($errors->has('approved'))
                    <div class="invalid-feedback">
                        {{ $errors->first('approved') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.approved_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="roles">{{ trans('cruds.user.fields.roles') }}</label>
                <div style="padding-bottom: 4px">
                    <span class="btn btn-info btn-xs select-all" style="border-radius: 0">{{ trans('global.select_all') }}</span>
                    <span class="btn btn-info btn-xs deselect-all" style="border-radius: 0">{{ trans('global.deselect_all') }}</span>
                </div>
                <select class="form-control select2 {{ $errors->has('roles') ? 'is-invalid' : '' }}" name="roles[]" id="roles" multiple required>
                    @foreach($roles as $id => $role)
                        <option value="{{ $id }}" {{ (in_array($id, old('roles', [])) || $user->roles->contains($id)) ? 'selected' : '' }}>{{ $role }}</option>
                    @endforeach
                </select>
                @if($errors->has('roles'))
                    <div class="invalid-feedback">
                        {{ $errors->first('roles') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.roles_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="aadhaar">{{ trans('cruds.user.fields.aadhaar') }}</label>
                <input class="form-control {{ $errors->has('aadhaar') ? 'is-invalid' : '' }}" type="text" name="aadhaar" id="aadhaar" value="{{ old('aadhaar', $user->aadhaar) }}" required>
                @if($errors->has('aadhaar'))
                    <div class="invalid-feedback">
                        {{ $errors->first('aadhaar') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.aadhaar_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="mobile_number">{{ trans('cruds.user.fields.mobile_number') }}</label>
                <input class="form-control {{ $errors->has('mobile_number') ? 'is-invalid' : '' }}" type="text" name="mobile_number" id="mobile_number" value="{{ old('mobile_number', $user->mobile_number) }}" required>
                @if($errors->has('mobile_number'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mobile_number') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.mobile_number_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="exporter_id">{{ trans('cruds.user.fields.exporter') }}</label>
                <select class="form-control select2 {{ $errors->has('exporter') ? 'is-invalid' : '' }}" name="exporter_id" id="exporter_id">
                    @foreach($exporters as $id => $entry)
                        <option value="{{ $id }}" {{ (old('exporter_id') ? old('exporter_id') : $user->exporter->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('exporter'))
                    <div class="invalid-feedback">
                        {{ $errors->first('exporter') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.exporter_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="import_export_code">{{ trans('cruds.user.fields.import_export_code') }}</label>
                <input class="form-control {{ $errors->has('import_export_code') ? 'is-invalid' : '' }}" type="text" name="import_export_code" id="import_export_code" value="{{ old('import_export_code', $user->import_export_code) }}" required>
                @if($errors->has('import_export_code'))
                    <div class="invalid-feedback">
                        {{ $errors->first('import_export_code') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.import_export_code_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="exporter_company_name">{{ trans('cruds.user.fields.exporter_company_name') }}</label>
                <input class="form-control {{ $errors->has('exporter_company_name') ? 'is-invalid' : '' }}" type="text" name="exporter_company_name" id="exporter_company_name" value="{{ old('exporter_company_name', $user->exporter_company_name) }}" required>
                @if($errors->has('exporter_company_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('exporter_company_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.exporter_company_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="contact_mobile_no">{{ trans('cruds.user.fields.contact_mobile_no') }}</label>
                <input class="form-control {{ $errors->has('contact_mobile_no') ? 'is-invalid' : '' }}" type="text" name="contact_mobile_no" id="contact_mobile_no" value="{{ old('contact_mobile_no', $user->contact_mobile_no) }}" required>
                @if($errors->has('contact_mobile_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('contact_mobile_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.contact_mobile_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="gst_number">{{ trans('cruds.user.fields.gst_number') }}</label>
                <input class="form-control {{ $errors->has('gst_number') ? 'is-invalid' : '' }}" type="text" name="gst_number" id="gst_number" value="{{ old('gst_number', $user->gst_number) }}">
                @if($errors->has('gst_number'))
                    <div class="invalid-feedback">
                        {{ $errors->first('gst_number') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.gst_number_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="pan_number">{{ trans('cruds.user.fields.pan_number') }}</label>
                <input class="form-control {{ $errors->has('pan_number') ? 'is-invalid' : '' }}" type="text" name="pan_number" id="pan_number" value="{{ old('pan_number', $user->pan_number) }}">
                @if($errors->has('pan_number'))
                    <div class="invalid-feedback">
                        {{ $errors->first('pan_number') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.pan_number_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="address">{{ trans('cruds.user.fields.address') }}</label>
                <textarea class="form-control {{ $errors->has('address') ? 'is-invalid' : '' }}" name="address" id="address" required>{{ old('address', $user->address) }}</textarea>
                @if($errors->has('address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.address_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="postal_code">{{ trans('cruds.user.fields.postal_code') }}</label>
                <input class="form-control {{ $errors->has('postal_code') ? 'is-invalid' : '' }}" type="text" name="postal_code" id="postal_code" value="{{ old('postal_code', $user->postal_code) }}">
                @if($errors->has('postal_code'))
                    <div class="invalid-feedback">
                        {{ $errors->first('postal_code') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.postal_code_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="self_sealing_approval_no">{{ trans('cruds.user.fields.self_sealing_approval_no') }}</label>
                <input class="form-control {{ $errors->has('self_sealing_approval_no') ? 'is-invalid' : '' }}" type="text" name="self_sealing_approval_no" id="self_sealing_approval_no" value="{{ old('self_sealing_approval_no', $user->self_sealing_approval_no) }}" required>
                @if($errors->has('self_sealing_approval_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('self_sealing_approval_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.self_sealing_approval_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="self_sealing_approval_date">{{ trans('cruds.user.fields.self_sealing_approval_date') }}</label>
                <input class="form-control {{ $errors->has('self_sealing_approval_date') ? 'is-invalid' : '' }}" type="text" name="self_sealing_approval_date" id="self_sealing_approval_date" value="{{ old('self_sealing_approval_date', $user->self_sealing_approval_date) }}" required>
                @if($errors->has('self_sealing_approval_date'))
                    <div class="invalid-feedback">
                        {{ $errors->first('self_sealing_approval_date') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.self_sealing_approval_date_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="self_sealing_approved_by">{{ trans('cruds.user.fields.self_sealing_approved_by') }}</label>
                <input class="form-control {{ $errors->has('self_sealing_approved_by') ? 'is-invalid' : '' }}" type="text" name="self_sealing_approved_by" id="self_sealing_approved_by" value="{{ old('self_sealing_approved_by', $user->self_sealing_approved_by) }}" required>
                @if($errors->has('self_sealing_approved_by'))
                    <div class="invalid-feedback">
                        {{ $errors->first('self_sealing_approved_by') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.self_sealing_approved_by_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="state_id">{{ trans('cruds.user.fields.state') }}</label>
                <select class="form-control select2 {{ $errors->has('state') ? 'is-invalid' : '' }}" name="state_id" id="state_id">
                    @foreach($states as $id => $entry)
                        <option value="{{ $id }}" {{ (old('state_id') ? old('state_id') : $user->state->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('state'))
                    <div class="invalid-feedback">
                        {{ $errors->first('state') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.state_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="city_id">{{ trans('cruds.user.fields.city') }}</label>
                <select class="form-control select2 {{ $errors->has('city') ? 'is-invalid' : '' }}" name="city_id" id="city_id">
                    @foreach($cities as $id => $entry)
                        <option value="{{ $id }}" {{ (old('city_id') ? old('city_id') : $user->city->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('city'))
                    <div class="invalid-feedback">
                        {{ $errors->first('city') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.city_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="commissionerate_address">{{ trans('cruds.user.fields.commissionerate_address') }}</label>
                <textarea class="form-control {{ $errors->has('commissionerate_address') ? 'is-invalid' : '' }}" name="commissionerate_address" id="commissionerate_address">{{ old('commissionerate_address', $user->commissionerate_address) }}</textarea>
                @if($errors->has('commissionerate_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('commissionerate_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.commissionerate_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="gst">{{ trans('cruds.user.fields.gst') }}</label>
                <div class="needsclick dropzone {{ $errors->has('gst') ? 'is-invalid' : '' }}" id="gst-dropzone">
                </div>
                @if($errors->has('gst'))
                    <div class="invalid-feedback">
                        {{ $errors->first('gst') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.gst_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="iec">{{ trans('cruds.user.fields.iec') }}</label>
                <div class="needsclick dropzone {{ $errors->has('iec') ? 'is-invalid' : '' }}" id="iec-dropzone">
                </div>
                @if($errors->has('iec'))
                    <div class="invalid-feedback">
                        {{ $errors->first('iec') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.iec_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="pan">{{ trans('cruds.user.fields.pan') }}</label>
                <div class="needsclick dropzone {{ $errors->has('pan') ? 'is-invalid' : '' }}" id="pan-dropzone">
                </div>
                @if($errors->has('pan'))
                    <div class="invalid-feedback">
                        {{ $errors->first('pan') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.pan_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="cancelled_cheque">{{ trans('cruds.user.fields.cancelled_cheque') }}</label>
                <div class="needsclick dropzone {{ $errors->has('cancelled_cheque') ? 'is-invalid' : '' }}" id="cancelled_cheque-dropzone">
                </div>
                @if($errors->has('cancelled_cheque'))
                    <div class="invalid-feedback">
                        {{ $errors->first('cancelled_cheque') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.cancelled_cheque_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="self_certification">{{ trans('cruds.user.fields.self_certification') }}</label>
                <div class="needsclick dropzone {{ $errors->has('self_certification') ? 'is-invalid' : '' }}" id="self_certification-dropzone">
                </div>
                @if($errors->has('self_certification'))
                    <div class="invalid-feedback">
                        {{ $errors->first('self_certification') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.self_certification_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="branch_id">{{ trans('cruds.user.fields.branch') }}</label>
                <select class="form-control select2 {{ $errors->has('branch') ? 'is-invalid' : '' }}" name="branch_id" id="branch_id">
                    @foreach($branches as $id => $entry)
                        <option value="{{ $id }}" {{ (old('branch_id') ? old('branch_id') : $user->branch->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('branch'))
                    <div class="invalid-feedback">
                        {{ $errors->first('branch') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.branch_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="team_id">{{ trans('cruds.user.fields.team') }}</label>
                <select class="form-control select2 {{ $errors->has('team') ? 'is-invalid' : '' }}" name="team_id" id="team_id">
                    @foreach($teams as $id => $entry)
                        <option value="{{ $id }}" {{ (old('team_id') ? old('team_id') : $user->team->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('team'))
                    <div class="invalid-feedback">
                        {{ $errors->first('team') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.user.fields.team_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection

@section('scripts')
<script>
    Dropzone.options.gstDropzone = {
    url: '{{ route('admin.users.storeMedia') }}',
    maxFilesize: 2, // MB
    maxFiles: 1,
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2
    },
    success: function (file, response) {
      $('form').find('input[name="gst"]').remove()
      $('form').append('<input type="hidden" name="gst" value="' + response.name + '">')
    },
    removedfile: function (file) {
      file.previewElement.remove()
      if (file.status !== 'error') {
        $('form').find('input[name="gst"]').remove()
        this.options.maxFiles = this.options.maxFiles + 1
      }
    },
    init: function () {
@if(isset($user) && $user->gst)
      var file = {!! json_encode($user->gst) !!}
          this.options.addedfile.call(this, file)
      file.previewElement.classList.add('dz-complete')
      $('form').append('<input type="hidden" name="gst" value="' + file.file_name + '">')
      this.options.maxFiles = this.options.maxFiles - 1
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}
</script>
<script>
    Dropzone.options.iecDropzone = {
    url: '{{ route('admin.users.storeMedia') }}',
    maxFilesize: 2, // MB
    maxFiles: 1,
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2
    },
    success: function (file, response) {
      $('form').find('input[name="iec"]').remove()
      $('form').append('<input type="hidden" name="iec" value="' + response.name + '">')
    },
    removedfile: function (file) {
      file.previewElement.remove()
      if (file.status !== 'error') {
        $('form').find('input[name="iec"]').remove()
        this.options.maxFiles = this.options.maxFiles + 1
      }
    },
    init: function () {
@if(isset($user) && $user->iec)
      var file = {!! json_encode($user->iec) !!}
          this.options.addedfile.call(this, file)
      file.previewElement.classList.add('dz-complete')
      $('form').append('<input type="hidden" name="iec" value="' + file.file_name + '">')
      this.options.maxFiles = this.options.maxFiles - 1
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}
</script>
<script>
    Dropzone.options.panDropzone = {
    url: '{{ route('admin.users.storeMedia') }}',
    maxFilesize: 2, // MB
    maxFiles: 1,
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2
    },
    success: function (file, response) {
      $('form').find('input[name="pan"]').remove()
      $('form').append('<input type="hidden" name="pan" value="' + response.name + '">')
    },
    removedfile: function (file) {
      file.previewElement.remove()
      if (file.status !== 'error') {
        $('form').find('input[name="pan"]').remove()
        this.options.maxFiles = this.options.maxFiles + 1
      }
    },
    init: function () {
@if(isset($user) && $user->pan)
      var file = {!! json_encode($user->pan) !!}
          this.options.addedfile.call(this, file)
      file.previewElement.classList.add('dz-complete')
      $('form').append('<input type="hidden" name="pan" value="' + file.file_name + '">')
      this.options.maxFiles = this.options.maxFiles - 1
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}
</script>
<script>
    Dropzone.options.cancelledChequeDropzone = {
    url: '{{ route('admin.users.storeMedia') }}',
    maxFilesize: 2, // MB
    maxFiles: 1,
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2
    },
    success: function (file, response) {
      $('form').find('input[name="cancelled_cheque"]').remove()
      $('form').append('<input type="hidden" name="cancelled_cheque" value="' + response.name + '">')
    },
    removedfile: function (file) {
      file.previewElement.remove()
      if (file.status !== 'error') {
        $('form').find('input[name="cancelled_cheque"]').remove()
        this.options.maxFiles = this.options.maxFiles + 1
      }
    },
    init: function () {
@if(isset($user) && $user->cancelled_cheque)
      var file = {!! json_encode($user->cancelled_cheque) !!}
          this.options.addedfile.call(this, file)
      file.previewElement.classList.add('dz-complete')
      $('form').append('<input type="hidden" name="cancelled_cheque" value="' + file.file_name + '">')
      this.options.maxFiles = this.options.maxFiles - 1
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}
</script>
<script>
    Dropzone.options.selfCertificationDropzone = {
    url: '{{ route('admin.users.storeMedia') }}',
    maxFilesize: 2, // MB
    maxFiles: 1,
    addRemoveLinks: true,
    headers: {
      'X-CSRF-TOKEN': "{{ csrf_token() }}"
    },
    params: {
      size: 2
    },
    success: function (file, response) {
      $('form').find('input[name="self_certification"]').remove()
      $('form').append('<input type="hidden" name="self_certification" value="' + response.name + '">')
    },
    removedfile: function (file) {
      file.previewElement.remove()
      if (file.status !== 'error') {
        $('form').find('input[name="self_certification"]').remove()
        this.options.maxFiles = this.options.maxFiles + 1
      }
    },
    init: function () {
@if(isset($user) && $user->self_certification)
      var file = {!! json_encode($user->self_certification) !!}
          this.options.addedfile.call(this, file)
      file.previewElement.classList.add('dz-complete')
      $('form').append('<input type="hidden" name="self_certification" value="' + file.file_name + '">')
      this.options.maxFiles = this.options.maxFiles - 1
@endif
    },
     error: function (file, response) {
         if ($.type(response) === 'string') {
             var message = response //dropzone sends it's own error messages in string
         } else {
             var message = response.errors.file
         }
         file.previewElement.classList.add('dz-error')
         _ref = file.previewElement.querySelectorAll('[data-dz-errormessage]')
         _results = []
         for (_i = 0, _len = _ref.length; _i < _len; _i++) {
             node = _ref[_i]
             _results.push(node.textContent = message)
         }

         return _results
     }
}
</script>
@endsection