<?php

Route::redirect('/', '/login');
Route::get('/home', function () {
    if (session('status')) {
        return redirect()->route('admin.home')->with('status', session('status'));
    }

    return redirect()->route('admin.home');
});

Auth::routes();

Route::group(['prefix' => 'admin', 'as' => 'admin.', 'namespace' => 'Admin', 'middleware' => ['auth']], function () {
    Route::get('/', 'HomeController@index')->name('home');
    // Permissions
    Route::delete('permissions/destroy', 'PermissionsController@massDestroy')->name('permissions.massDestroy');
    Route::resource('permissions', 'PermissionsController');

    // Roles
    Route::delete('roles/destroy', 'RolesController@massDestroy')->name('roles.massDestroy');
    Route::resource('roles', 'RolesController');

    // Users
    Route::delete('users/destroy', 'UsersController@massDestroy')->name('users.massDestroy');
    Route::post('users/media', 'UsersController@storeMedia')->name('users.storeMedia');
    Route::post('users/ckmedia', 'UsersController@storeCKEditorImages')->name('users.storeCKEditorImages');
    Route::resource('users', 'UsersController');

    // Ports
    Route::delete('ports/destroy', 'PortsController@massDestroy')->name('ports.massDestroy');
    Route::post('ports/parse-csv-import', 'PortsController@parseCsvImport')->name('ports.parseCsvImport');
    Route::post('ports/process-csv-import', 'PortsController@processCsvImport')->name('ports.processCsvImport');
    Route::resource('ports', 'PortsController');

    // Registered Exporters
    Route::delete('registered-exporters/destroy', 'RegisteredExportersController@massDestroy')->name('registered-exporters.massDestroy');
    Route::post('registered-exporters/media', 'RegisteredExportersController@storeMedia')->name('registered-exporters.storeMedia');
    Route::post('registered-exporters/ckmedia', 'RegisteredExportersController@storeCKEditorImages')->name('registered-exporters.storeCKEditorImages');
    Route::post('registered-exporters/parse-csv-import', 'RegisteredExportersController@parseCsvImport')->name('registered-exporters.parseCsvImport');
    Route::post('registered-exporters/process-csv-import', 'RegisteredExportersController@processCsvImport')->name('registered-exporters.processCsvImport');
    Route::resource('registered-exporters', 'RegisteredExportersController');

    // Esealtracking
    Route::delete('esealtrackings/destroy', 'EsealtrackingController@massDestroy')->name('esealtrackings.massDestroy');
    Route::post('esealtrackings/parse-csv-import', 'EsealtrackingController@parseCsvImport')->name('esealtrackings.parseCsvImport');
    Route::post('esealtrackings/process-csv-import', 'EsealtrackingController@processCsvImport')->name('esealtrackings.processCsvImport');
    Route::resource('esealtrackings', 'EsealtrackingController');

    // States
    Route::delete('states/destroy', 'StatesController@massDestroy')->name('states.massDestroy');
    Route::post('states/parse-csv-import', 'StatesController@parseCsvImport')->name('states.parseCsvImport');
    Route::post('states/process-csv-import', 'StatesController@processCsvImport')->name('states.processCsvImport');
    Route::resource('states', 'StatesController');

    // Cities
    Route::delete('cities/destroy', 'CitiesController@massDestroy')->name('cities.massDestroy');
    Route::post('cities/parse-csv-import', 'CitiesController@parseCsvImport')->name('cities.parseCsvImport');
    Route::post('cities/process-csv-import', 'CitiesController@processCsvImport')->name('cities.processCsvImport');
    Route::resource('cities', 'CitiesController');

    // Order
    Route::delete('orders/destroy', 'OrderController@massDestroy')->name('orders.massDestroy');
    Route::post('orders/parse-csv-import', 'OrderController@parseCsvImport')->name('orders.parseCsvImport');
    Route::post('orders/process-csv-import', 'OrderController@processCsvImport')->name('orders.processCsvImport');
    Route::resource('orders', 'OrderController');

    // Seals
    Route::delete('seals/destroy', 'SealsController@massDestroy')->name('seals.massDestroy');
    Route::post('seals/parse-csv-import', 'SealsController@parseCsvImport')->name('seals.parseCsvImport');
    Route::post('seals/process-csv-import', 'SealsController@processCsvImport')->name('seals.processCsvImport');
    Route::resource('seals', 'SealsController');

    // Export
    Route::delete('exports/destroy', 'ExportController@massDestroy')->name('exports.massDestroy');
    Route::post('exports/parse-csv-import', 'ExportController@parseCsvImport')->name('exports.parseCsvImport');
    Route::post('exports/process-csv-import', 'ExportController@processCsvImport')->name('exports.processCsvImport');
    Route::resource('exports', 'ExportController');

    // Container Size
    Route::delete('container-sizes/destroy', 'ContainerSizeController@massDestroy')->name('container-sizes.massDestroy');
    Route::post('container-sizes/parse-csv-import', 'ContainerSizeController@parseCsvImport')->name('container-sizes.parseCsvImport');
    Route::post('container-sizes/process-csv-import', 'ContainerSizeController@processCsvImport')->name('container-sizes.processCsvImport');
    Route::resource('container-sizes', 'ContainerSizeController');

    // Team
    Route::delete('teams/destroy', 'TeamController@massDestroy')->name('teams.massDestroy');
    Route::resource('teams', 'TeamController');

    // User Alerts
    Route::delete('user-alerts/destroy', 'UserAlertsController@massDestroy')->name('user-alerts.massDestroy');
    Route::get('user-alerts/read', 'UserAlertsController@read');
    Route::resource('user-alerts', 'UserAlertsController', ['except' => ['edit', 'update']]);

    // Supliers
    Route::delete('supliers/destroy', 'SupliersController@massDestroy')->name('supliers.massDestroy');
    Route::post('supliers/parse-csv-import', 'SupliersController@parseCsvImport')->name('supliers.parseCsvImport');
    Route::post('supliers/process-csv-import', 'SupliersController@processCsvImport')->name('supliers.processCsvImport');
    Route::resource('supliers', 'SupliersController');

    // Expense Category
    Route::delete('expense-categories/destroy', 'ExpenseCategoryController@massDestroy')->name('expense-categories.massDestroy');
    Route::resource('expense-categories', 'ExpenseCategoryController');

    // Income Category
    Route::delete('income-categories/destroy', 'IncomeCategoryController@massDestroy')->name('income-categories.massDestroy');
    Route::resource('income-categories', 'IncomeCategoryController');

    // Expense
    Route::delete('expenses/destroy', 'ExpenseController@massDestroy')->name('expenses.massDestroy');
    Route::resource('expenses', 'ExpenseController');

    // Income
    Route::delete('incomes/destroy', 'IncomeController@massDestroy')->name('incomes.massDestroy');
    Route::resource('incomes', 'IncomeController');

    // Expense Report
    Route::delete('expense-reports/destroy', 'ExpenseReportController@massDestroy')->name('expense-reports.massDestroy');
    Route::resource('expense-reports', 'ExpenseReportController');

    // Task Status
    Route::delete('task-statuses/destroy', 'TaskStatusController@massDestroy')->name('task-statuses.massDestroy');
    Route::resource('task-statuses', 'TaskStatusController');

    // Task Tag
    Route::delete('task-tags/destroy', 'TaskTagController@massDestroy')->name('task-tags.massDestroy');
    Route::resource('task-tags', 'TaskTagController');

    // Task
    Route::delete('tasks/destroy', 'TaskController@massDestroy')->name('tasks.massDestroy');
    Route::post('tasks/media', 'TaskController@storeMedia')->name('tasks.storeMedia');
    Route::post('tasks/ckmedia', 'TaskController@storeCKEditorImages')->name('tasks.storeCKEditorImages');
    Route::resource('tasks', 'TaskController');

    // Tasks Calendar
    Route::resource('tasks-calendars', 'TasksCalendarController', ['except' => ['create', 'store', 'edit', 'update', 'show', 'destroy']]);

    // Branches
    Route::delete('branches/destroy', 'BranchesController@massDestroy')->name('branches.massDestroy');
    Route::resource('branches', 'BranchesController');

    // Add Branch
    Route::delete('add-branches/destroy', 'AddBranchController@massDestroy')->name('add-branches.massDestroy');
    Route::post('add-branches/media', 'AddBranchController@storeMedia')->name('add-branches.storeMedia');
    Route::post('add-branches/ckmedia', 'AddBranchController@storeCKEditorImages')->name('add-branches.storeCKEditorImages');
    Route::resource('add-branches', 'AddBranchController');

    Route::get('system-calendar', 'SystemCalendarController@index')->name('systemCalendar');
    Route::get('global-search', 'GlobalSearchController@search')->name('globalSearch');
    Route::get('team-members', 'TeamMembersController@index')->name('team-members.index');
    Route::post('team-members', 'TeamMembersController@invite')->name('team-members.invite');

        Route::get('portstatus', 'PortsController@portstatus');
        Route::get('userprofile', 'UsersController@userprofile');
        Route::get('addbranch', 'UsersController@AddBranch');
        Route::post('postbranch', 'UsersController@postbranch');
        Route::get('pdfexports/{id}','ExportController@pdfexports');
        Route::post('exportdaterange', 'EsealtrackingController@exportdaterange');
});
Route::group(['prefix' => 'profile', 'as' => 'profile.', 'namespace' => 'Auth', 'middleware' => ['auth']], function () {
    // Change password
    if (file_exists(app_path('Http/Controllers/Auth/ChangePasswordController.php'))) {
        Route::get('password', 'ChangePasswordController@edit')->name('password.edit');
        Route::post('password', 'ChangePasswordController@update')->name('password.update');
        Route::post('profile', 'ChangePasswordController@updateProfile')->name('password.updateProfile');
        Route::post('profile/destroy', 'ChangePasswordController@destroy')->name('password.destroyProfile');
    }
});
